@@ -101,3 +101,8 @@ QString WebPage::userAgentForUrl(const QUrl &url) const
     return QWebPage::userAgentForUrl(url);
 #endif
 }
+
+void Browser::on_actionVisualizza_nel_browser_triggered()
+{
+    QDesktopServices::openUrl(ui->webView->url());
+}
