@@ -8,14 +8,7 @@ Se sei sicuro premi OK, altrimenti CANCEL";echo $?`
 				if [ "$ricrem" -eq "0" ]
 					then
 						mkdir /home/user/MyDocs/Puntate\ Servizio\ Pubblico/ 1>/dev/null 2>/dev/null
-						if [ `id -u` != 0 ] ; then
-    exec youtube-dl http://www.youtube.com/watch?v=bnKDv2ELw0Y -o /home/user/MyDocs/Puntate\ Servizio\ Pubblico/$video.mp4 <<EOF
-exec sh $0 $*
-EOF
-	exit $?
-fi 
-
-osso-xterm
+						osso-xterm -e "youtube-dl http://www.youtube.com/watch?v=bnKDv2ELw0Y -o /home/user/MyDocs/Puntate\ Servizio\ Pubblico/$video.mp4"
 					else
 						dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Annullato!"
 				fi
